@@ -18,12 +18,21 @@ def converter(
     """Turns a list of question objects into Lambda Feedback JSON.
 
     Args:
-        template: The loaded JSON from the minimal template.
+        template: The loaded JSON from the minimal template (it needs to be in sync).
         ListQuestions: A list of question objects.
         output_dir: The absolute path for where to produced the final JSON/zip files.
     """
     # Create output by copying template
 
+    # create directory to put the questions
+    os.makedirs(output_dir, exist_ok=True)
+    output_question = os.path.join(output_dir, "set")
+    os.makedirs(output_question, exist_ok=True)
+
+    # create directory to put images - should be in set
+    output_image = os.path.join(output_question, "media")
+    os.makedirs(output_image, exist_ok=True)
+
     for i in range(len(ListQuestions)):
         output = deepcopy(template)
 
@@ -39,27 +48,19 @@ def converter(
         # add parts to the question file
         if ListQuestions[i].parts:
             output["parts"][0]["content"] = ListQuestions[i].parts[0].text
-            output["parts"][0]["workedSolution"][0]["content"] = (
+            output["parts"][0]["workedSolution"]["content"] = (
                 ListQuestions[i].parts[0].worked_solution
             )
             for j in range(1, len(ListQuestions[i].parts)):
                 output["parts"].append(deepcopy(template["parts"][0]))
                 output["parts"][j]["content"] = ListQuestions[i].parts[j].text
-                output["parts"][j]["workedSolution"][0]["content"] = (
+                output["parts"][j]["orderNumber"] = j
+                output["parts"][j]["workedSolution"]["content"] = (
                     ListQuestions[i].parts[j].worked_solution
                 )
 
         # Output file
-        filename = "Question " + str(i + 1)
-
-        # create directory to put the questions
-        os.makedirs(output_dir, exist_ok=True)
-        output_question = os.path.join(output_dir, filename)
-        os.makedirs(output_question, exist_ok=True)
-
-        # create directory to put image
-        output_image = os.path.join(output_question, "media")
-        os.makedirs(output_image, exist_ok=True)
+        filename = "question_" + str(i + 1)
 
         # write questions into directory
         with open(f"{output_question}/{filename}.json", "w") as file:
